@@ -1,13 +1,16 @@
+from abc import ABCMeta, abstractmethod
 from typing import Any
 
 from .IMotion import IMotion
 
 
-class IFocuser(IMotion):
+class IFocuser(IMotion, metaclass=ABCMeta):
     """The module is a focusing device."""
-    __module__ = 'pyobs.interfaces'
 
-    def set_focus(self, focus: float, **kwargs: Any) -> None:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def set_focus(self, focus: float, **kwargs: Any) -> None:
         """Sets new focus.
 
         Args:
@@ -16,9 +19,10 @@ class IFocuser(IMotion):
         Raises:
             InterruptedError: If focus was interrupted.
         """
-        raise NotImplementedError
+        ...
 
-    def set_focus_offset(self, offset: float, **kwargs: Any) -> None:
+    @abstractmethod
+    async def set_focus_offset(self, offset: float, **kwargs: Any) -> None:
         """Sets focus offset.
 
         Args:
@@ -27,23 +31,25 @@ class IFocuser(IMotion):
         Raises:
             InterruptedError: If focus was interrupted.
         """
-        raise NotImplementedError
+        ...
 
-    def get_focus(self, **kwargs: Any) -> float:
+    @abstractmethod
+    async def get_focus(self, **kwargs: Any) -> float:
         """Return current focus.
 
         Returns:
             Current focus.
         """
-        raise NotImplementedError
+        ...
 
-    def get_focus_offset(self, **kwargs: Any) -> float:
+    @abstractmethod
+    async def get_focus_offset(self, **kwargs: Any) -> float:
         """Return current focus offset.
 
         Returns:
             Current focus offset.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IFocuser']
+__all__ = ["IFocuser"]
