@@ -1,3 +1,4 @@
+from abc import ABCMeta, abstractmethod
 from enum import Enum
 from typing import Any, Optional
 
@@ -5,27 +6,31 @@ from .IReady import IReady
 from pyobs.utils.enums import MotionStatus
 
 
-class IMotion(IReady):
+class IMotion(IReady, metaclass=ABCMeta):
     """The module controls a device that can move."""
-    __module__ = 'pyobs.interfaces'
 
-    def init(self, **kwargs: Any) -> None:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def init(self, **kwargs: Any) -> None:
         """Initialize device.
 
         Raises:
             ValueError: If device could not be initialized.
         """
-        raise NotImplementedError
+        ...
 
-    def park(self, **kwargs: Any) -> None:
+    @abstractmethod
+    async def park(self, **kwargs: Any) -> None:
         """Park device.
 
         Raises:
             ValueError: If device could not be parked.
         """
-        raise NotImplementedError
+        ...
 
-    def get_motion_status(self, device: Optional[str] = None, **kwargs: Any) -> MotionStatus:
+    @abstractmethod
+    async def get_motion_status(self, device: Optional[str] = None, **kwargs: Any) -> MotionStatus:
         """Returns current motion status.
 
         Args:
@@ -34,15 +39,16 @@ class IMotion(IReady):
         Returns:
             A string from the Status enumerator.
         """
-        raise NotImplementedError
+        ...
 
-    def stop_motion(self, device: Optional[str] = None, **kwargs: Any) -> None:
+    @abstractmethod
+    async def stop_motion(self, device: Optional[str] = None, **kwargs: Any) -> None:
         """Stop the motion.
 
         Args:
             device: Name of device to stop, or None for all.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IMotion']
+__all__ = ["IMotion"]
