@@ -1,14 +1,17 @@
+from abc import ABCMeta, abstractmethod
 from typing import Tuple, Any
 
 from .interface import Interface
 
 
-class IOffsetsRaDec(Interface):
+class IOffsetsRaDec(Interface, metaclass=ABCMeta):
     """The module supports RA/Dec offsets, usually combined with :class:`~pyobs.interfaces.ITelescope` and
     :class:`~pyobs.interfaces.IRaDec`."""
-    __module__ = 'pyobs.interfaces'
 
-    def set_offsets_radec(self, dra: float, ddec: float, **kwargs: Any) -> None:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def set_offsets_radec(self, dra: float, ddec: float, **kwargs: Any) -> None:
         """Move an RA/Dec offset.
 
         Args:
@@ -18,15 +21,16 @@ class IOffsetsRaDec(Interface):
         Raises:
             ValueError: If offset could not be set.
         """
-        raise NotImplementedError
+        ...
 
-    def get_offsets_radec(self, **kwargs: Any) -> Tuple[float, float]:
+    @abstractmethod
+    async def get_offsets_radec(self, **kwargs: Any) -> Tuple[float, float]:
         """Get RA/Dec offset.
 
         Returns:
             Tuple with RA and Dec offsets.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IOffsetsRaDec']
+__all__ = ["IOffsetsRaDec"]
