@@ -1,13 +1,16 @@
+from abc import ABCMeta, abstractmethod
 from typing import Tuple, Any
 
 from .interface import Interface
 
 
-class IPointingHGS(Interface):
+class IPointingHGS(Interface, metaclass=ABCMeta):
     """The module can move to Mu/Psi coordinates, usually combined with :class:`~pyobs.interfaces.ITelescope`."""
-    __module__ = 'pyobs.interfaces'
 
-    def move_hgs_lon_lat(self, lon: float, lat: float, **kwargs: Any) -> None:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def move_hgs_lon_lat(self, lon: float, lat: float, **kwargs: Any) -> None:
         """Moves on given coordinates.
 
         Args:
@@ -17,15 +20,16 @@ class IPointingHGS(Interface):
         Raises:
             ValueError: If device could not move.
         """
-        raise NotImplementedError
+        ...
 
-    def get_hgs_lon_lat(self, **kwargs: Any) -> Tuple[float, float]:
+    @abstractmethod
+    async def get_hgs_lon_lat(self, **kwargs: Any) -> Tuple[float, float]:
         """Returns current longitude and latitude position.
 
         Returns:
             Tuple of current lon, lat in degrees.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IPointingHGS']
+__all__ = ["IPointingHGS"]
