@@ -1,6 +1,7 @@
+import asyncio
 import datetime
 import logging
-import threading
+from abc import ABCMeta, abstractmethod
 from typing import Tuple, Optional, Dict, Any, NamedTuple, List
 from astropy.io import fits
 
@@ -16,16 +17,22 @@ log = logging.getLogger(__name__)
 
 class ExposureInfo(NamedTuple):
     """Info about a running exposure."""
+
     start: datetime.datetime
 
 
-class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
+class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph, metaclass=ABCMeta):
     """Base class for all spectrograph modules."""
-    __module__ = 'pyobs.modules.camera'
 
-    def __init__(self, fits_headers: Optional[Dict[str, Any]] = None,
-                 filenames: str = '/cache/pyobs-{DAY-OBS|date:}-{FRAMENUM|string:04d}.fits.gz',
-                 fits_namespaces: Optional[List[str]] = None, **kwargs: Any):
+    __module__ = "pyobs.modules.camera"
+
+    def __init__(
+        self,
+        fits_headers: Optional[Dict[str, Any]] = None,
+        filenames: str = "/cache/pyobs-{DAY-OBS|date:}-{FRAMENUM|string:04d}.fits.gz",
+        fits_namespaces: Optional[List[str]] = None,
+        **kwargs: Any,
+    ):
         """Creates a new BaseCamera.
 
         Args:
@@ -35,22 +42,24 @@ class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
             fits_namespaces: List of namespaces for FITS headers that this camera should request
         """
         Module.__init__(self, **kwargs)
-        SpectrumFitsHeaderMixin.__init__(self, fits_namespaces=fits_namespaces, fits_headers=fits_headers,
-                                         filenames=filenames)
+        SpectrumFitsHeaderMixin.__init__(
+            self, fits_namespaces=fits_namespaces, fits_headers=fits_headers, filenames=filenames
+        )
 
         # init camera
         self._exposure: Optional[ExposureInfo] = None
         self._spectrograph_status = ExposureStatus.IDLE
 
         # multi-threading
-        self._expose_lock = threading.Lock()
-        self.expose_abort = threading.Event()
+        self._expose_lock = asyncio.Lock()
+        self.expose_abort = asyncio.Event()
 
         # check
         if self.comm is None:
-            log.warning('No comm module given, will not be able to signal new images!')
+            log.warning("No comm module given, will not be able to signal new images!")
 
-    def _expose(self, abort_event: threading.Event) -> fits.HDUList:
+    @abstractmethod
+    async def _expose(self, abort_event: asyncio.Event) -> fits.HDUList:
         """Actually do the exposure, should be implemented by derived classes.
 
         Args:
@@ -62,14 +71,12 @@ class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
         Raises:
             ValueError: If exposure was not successful.
         """
-        raise NotImplementedError
+        ...
 
-    def __expose(self, broadcast: bool) -> Tuple[Optional[fits.HDUList], Optional[str]]:
+    async def __expose(self, broadcast: bool) -> Tuple[Optional[fits.HDUList], Optional[str]]:
         """Wrapper for a single exposure.
 
         Args:
-            exposure_time: The requested exposure time in seconds.
-            open_shutter: Whether or not to open the shutter.
             broadcast: Whether or not the new image should be broadcasted.
 
         Returns:
@@ -80,12 +87,12 @@ class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
         """
 
         # request fits headers
-        header_futures_before = self.request_fits_headers(before=True)
+        header_futures_before = await self.request_fits_headers(before=True)
 
         # do the exposure
         self._exposure = ExposureInfo(start=datetime.datetime.utcnow())
         try:
-            hdulist = self._expose(abort_event=self.expose_abort)
+            hdulist = await self._expose(abort_event=self.expose_abort)
             if hdulist is None or hdulist[0].data is None:
                 self._exposure = None
                 return None, None
@@ -95,15 +102,15 @@ class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
             raise
 
         # request fits headers again
-        header_futures_after = self.request_fits_headers(before=False)
+        header_futures_after = await self.request_fits_headers(before=False)
 
         # add HDU name
-        hdulist[0].header['EXTNAME'] = 'SCI'
+        hdulist[0].header["EXTNAME"] = "SCI"
 
         # add fits headers and format filename
-        self.add_requested_fits_headers(hdulist[0], header_futures_before)
-        self.add_requested_fits_headers(hdulist[0], header_futures_after)
-        self.add_fits_headers(hdulist[0])
+        await self.add_requested_fits_headers(hdulist[0], header_futures_before)
+        await self.add_requested_fits_headers(hdulist[0], header_futures_after)
+        await self.add_fits_headers(hdulist[0])
 
         # format filename
         filename = self.format_filename(hdulist[0])
@@ -114,23 +121,23 @@ class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
 
         # upload file
         try:
-            log.info('Uploading spectrum to file server...')
-            self.vfs.write_fits(filename, hdulist)
+            log.info("Uploading spectrum to file server...")
+            await self.vfs.write_fits(filename, hdulist)
         except FileNotFoundError:
-            raise ValueError('Could not upload spectrum.')
+            raise ValueError("Could not upload spectrum.")
 
         # broadcast image path
         if broadcast and self.comm:
-            log.info('Broadcasting spectrum ID...')
-            self.comm.send_event(NewSpectrumEvent(filename))
+            log.info("Broadcasting spectrum ID...")
+            await self.comm.send_event(NewSpectrumEvent(filename))
 
         # return spectrum and unique
         self._exposure = None
-        log.info('Finished spectrum %s.', filename)
+        log.info("Finished spectrum %s.", filename)
         return hdulist, filename
 
     @timeout(10)
-    def grab_spectrum(self, broadcast: bool = True, **kwargs: Any) -> str:
+    async def grab_spectrum(self, broadcast: bool = True, **kwargs: Any) -> str:
         """Grabs a spectrum and returns reference.
 
         Args:
@@ -139,34 +146,25 @@ class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
         Returns:
             Name of image that was taken.
         """
-        # acquire lock
-        log.info('Acquiring exclusive lock on spectrograph...')
-        if not self._expose_lock.acquire(blocking=False):
-            raise ValueError('Could not acquire spectrograph lock for grab_spectrum().')
 
-        # make sure that we release the lock
-        try:
-            # are we exposing?
-            if self._spectrograph_status != ExposureStatus.IDLE:
-                raise ValueError('Cannot start new exposure because spectrograph is not idle.')
+        # are we exposing?
+        if self._spectrograph_status != ExposureStatus.IDLE:
+            raise ValueError("Cannot start new exposure because spectrograph is not idle.")
+        await self._change_exposure_status(ExposureStatus.EXPOSING)
 
-            # expose
-            hdu, filename = self.__expose(broadcast)
-            if hdu is None:
-                raise ValueError('Could not take spectrum.')
-            else:
-                if filename is None:
-                    raise ValueError('Spectrum has not been saved, so cannot be retrieved by filename.')
+        # expose
+        hdu, filename = await self.__expose(broadcast)
+        if hdu is None:
+            raise ValueError("Could not take spectrum.")
+        else:
+            if filename is None:
+                raise ValueError("Spectrum has not been saved, so cannot be retrieved by filename.")
 
-            # return filename
-            return filename
+        # return filename
+        await self._change_exposure_status(ExposureStatus.IDLE)
+        return filename
 
-        finally:
-            # release lock
-            log.info('Releasing exclusive lock on spectrograph...')
-            self._expose_lock.release()
-
-    def _change_exposure_status(self, status: ExposureStatus) -> None:
+    async def _change_exposure_status(self, status: ExposureStatus) -> None:
         """Change exposure status and send event,
 
         Args:
@@ -175,12 +173,12 @@ class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
 
         # send event, if it changed
         if self._spectrograph_status != status:
-            self.comm.send_event(ExposureStatusChangedEvent(last=self._spectrograph_status, current=status))
+            await self.comm.send_event(ExposureStatusChangedEvent(last=self._spectrograph_status, current=status))
 
         # set it
         self._spectrograph_status = status
 
-    def get_exposure_status(self, **kwargs: Any) -> ExposureStatus:
+    async def get_exposure_status(self, **kwargs: Any) -> ExposureStatus:
         """Returns the current status of the spectrograph, which is one of 'idle', 'exposing', or 'readout'.
 
         Returns:
@@ -188,7 +186,7 @@ class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
         """
         return self._spectrograph_status
 
-    def abort(self, **kwargs: Any) -> None:
+    async def abort(self, **kwargs: Any) -> None:
         """Aborts the current exposure.
 
         Raises:
@@ -197,4 +195,4 @@ class BaseSpectrograph(Module, SpectrumFitsHeaderMixin, ISpectrograph):
         pass
 
 
-__all__ = ['BaseSpectrograph']
+__all__ = ["BaseSpectrograph"]
