@@ -2,14 +2,12 @@ import logging
 import threading
 import time
 from datetime import datetime
-from typing import Dict, Any, Optional, TYPE_CHECKING, Tuple
+from typing import Any
 import numpy as np
 from astropy.io import fits
 
 from pyobs.modules.camera.basespectrograph import BaseSpectrograph
 from pyobs.utils.enums import ExposureStatus
-if TYPE_CHECKING:
-    from pyobs.utils.simulation import SimWorld
 
 
 log = logging.getLogger(__name__)
@@ -17,7 +15,8 @@ log = logging.getLogger(__name__)
 
 class DummySpectrograph(BaseSpectrograph):
     """A dummy spectrograph for testing."""
-    __module__ = 'pyobs.modules.camera'
+
+    __module__ = "pyobs.modules.camera"
 
     def __init__(self, **kwargs: Any):
         """Creates a new dummy cammera.
@@ -28,7 +27,7 @@ class DummySpectrograph(BaseSpectrograph):
         """
         BaseSpectrograph.__init__(self, **kwargs)
 
-    def _expose(self, abort_event: threading.Event) -> fits.HDUList:
+    async def _expose(self, abort_event: threading.Event) -> fits.HDUList:
         """Actually do the exposure, should be implemented by derived classes.
 
         Args:
@@ -42,22 +41,21 @@ class DummySpectrograph(BaseSpectrograph):
         """
 
         # do exposure
-        log.info('Starting exposure...')
-        exposure_time = 1.
+        log.info("Starting exposure...")
+        exposure_time = 1.0
         date_obs = datetime.utcnow()
-        self._change_exposure_status(ExposureStatus.EXPOSING)
         self._exposing = True
         steps = 10
         for i in range(steps):
             if abort_event.is_set() or not self._exposing:
                 self._exposing = False
-                self._change_exposure_status(ExposureStatus.IDLE)
-                raise ValueError('Exposure was aborted.')
+                await self._change_exposure_status(ExposureStatus.IDLE)
+                raise ValueError("Exposure was aborted.")
             time.sleep(exposure_time / steps)
         self._exposing = False
 
         # readout
-        self._change_exposure_status(ExposureStatus.READOUT)
+        await self._change_exposure_status(ExposureStatus.READOUT)
         time.sleep(1)
 
         # get data
@@ -68,13 +66,12 @@ class DummySpectrograph(BaseSpectrograph):
         hdu = fits.PrimaryHDU(y)
 
         # add headers
-        hdu.header['DATE-OBS'] = date_obs.strftime("%Y-%m-%dT%H:%M:%S.%f")
-        hdu.header['CRVAL1'] = 5000
-        hdu.header['CDELT1'] = 1
+        hdu.header["DATE-OBS"] = date_obs.strftime("%Y-%m-%dT%H:%M:%S.%f")
+        hdu.header["CRVAL1"] = 5000
+        hdu.header["CDELT1"] = 1
 
         # finished
-        log.info('Exposure finished.')
-        self._change_exposure_status(ExposureStatus.IDLE)
+        log.info("Exposure finished.")
         return fits.HDUList([hdu])
 
     def _abort_exposure(self) -> None:
@@ -85,13 +82,13 @@ class DummySpectrograph(BaseSpectrograph):
         """
         self._exposing = False
 
-    def get_exposure_progress(self, **kwargs: Any) -> float:
+    async def get_exposure_progress(self, **kwargs: Any) -> float:
         """Returns the progress of the current exposure in percent.
 
         Returns:
             Progress of the current exposure in percent.
         """
-        return 1.
+        return 1.0
 
 
-__all__ = ['DummySpectrograph']
+__all__ = ["DummySpectrograph"]
