@@ -1,3 +1,4 @@
+import asyncio
 import logging
 import threading
 from typing import Union, List, Dict, Tuple, Any, Optional
@@ -18,10 +19,12 @@ log = logging.getLogger(__name__)
 
 class Mastermind(Module, IAutonomous, IFitsHeaderBefore):
     """Mastermind for a full robotic mode."""
-    __module__ = 'pyobs.modules.robotic'
 
-    def __init__(self, tasks: Union[TaskArchive, dict], allowed_late_start: int = 300, allowed_overrun: int = 300,
-                 **kwargs: Any):
+    __module__ = "pyobs.modules.robotic"
+
+    def __init__(
+        self, tasks: Union[TaskArchive, dict], allowed_late_start: int = 300, allowed_overrun: int = 300, **kwargs: Any
+    ):
         """Initialize a new auto focus system.
 
         Args:
@@ -37,66 +40,55 @@ class Mastermind(Module, IAutonomous, IFitsHeaderBefore):
         self._running = False
 
         # add thread func
-        self.add_thread_func(self._run_thread, True)
+        self.add_background_task(self._run_thread, True)
 
         # get task archive
-        self._task_archive: TaskArchive = get_object(tasks, object_class=TaskArchive,
-                                                     comm=self.comm, vfs=self.vfs, observer=self.observer)
+        self._task_archive = self.add_child_object(tasks, TaskArchive)
 
         # observation name and exposure number
         self._task = None
         self._obs = None
         self._exp = None
 
-    def open(self):
+    async def open(self):
         """Open module."""
-        Module.open(self)
+        await Module.open(self)
 
         # subscribe to events
         if self.comm:
-            self.comm.register_event(TaskStartedEvent)
-            self.comm.register_event(TaskFinishedEvent)
+            await self.comm.register_event(TaskStartedEvent)
+            await self.comm.register_event(TaskFinishedEvent)
 
         # start
         self._running = True
 
-        # open scheduler
-        self._task_archive.open()
-
-    def close(self):
-        """Close module."""
-        Module.close(self)
-
-        # close scheduler
-        self._task_archive.close()
-
-    def start(self, **kwargs: Any):
+    async def start(self, **kwargs: Any):
         """Starts a service."""
-        log.info('Starting robotic system...')
+        log.info("Starting robotic system...")
         self._running = True
 
-    def stop(self, **kwargs: Any):
+    async def stop(self, **kwargs: Any):
         """Stops a service."""
-        log.info('Stopping robotic system...')
+        log.info("Stopping robotic system...")
         self._running = False
 
-    def is_running(self, **kwargs: Any) -> bool:
+    async def is_running(self, **kwargs: Any) -> bool:
         """Whether a service is running."""
         return self._running
 
-    def _run_thread(self):
+    async def _run_thread(self):
         # wait a little
-        self.closing.wait(1)
+        await asyncio.sleep(1)
 
         # flags
         first_late_start_warning = True
 
         # run until closed
-        while not self.closing.is_set():
+        while True:
             # not running?
             if not self._running:
                 # sleep a little and continue
-                self.closing.wait(1)
+                await asyncio.sleep(1)
                 continue
 
             # get now
@@ -104,9 +96,9 @@ class Mastermind(Module, IAutonomous, IFitsHeaderBefore):
 
             # find task that we want to run now
             task: Task = self._task_archive.get_task(now)
-            if task is None or not task.can_run():
+            if task is None or not await task.can_run():
                 # no task found
-                self.closing.wait(10)
+                await asyncio.sleep(10)
                 continue
 
             # starting too late?
@@ -115,12 +107,15 @@ class Mastermind(Module, IAutonomous, IFitsHeaderBefore):
                 if late_start > self._allowed_late_start * u.second:
                     # only warn once
                     if first_late_start_warning:
-                        log.warning('Time since start of window (%.1f) too long (>%.1f), skipping task...',
-                                    late_start.to_value('second'), self._allowed_late_start)
+                        log.warning(
+                            "Time since start of window (%.1f) too long (>%.1f), skipping task...",
+                            late_start.to_value("second"),
+                            self._allowed_late_start,
+                        )
                     first_late_start_warning = False
 
                     # sleep a little and skip
-                    self.closing.wait(10)
+                    await asyncio.sleep(10)
                     continue
 
             # reset warning
@@ -133,40 +128,22 @@ class Mastermind(Module, IAutonomous, IFitsHeaderBefore):
             eta = now + self._task.duration * u.second
 
             # send event
-            self.comm.send_event(TaskStartedEvent(name=self._task.name, id=self._task.id, eta=eta))
+            await self.comm.send_event(TaskStartedEvent(name=self._task.name, id=self._task.id, eta=eta))
 
             # run task in thread
-            log.info('Running task %s...', self._task.name)
-            abort_event = threading.Event()
-            task_thread = threading.Thread(target=self._task_archive.run_task, args=(self._task, abort_event))
-            task_thread.start()
-
-            # wait for it
-            while True:
-                # not alive anymore?
-                if not task_thread.is_alive():
-                    # finished
-                    break
-
-                # closing?
-                if self.closing.is_set() or Time.now() > task.end + self._allowed_overrun * u.second:
-                    # set event and wait for thread
-                    abort_event.set()
-                    task_thread.join()
-                    break
-
-                # just sleep a little and wait
-                self.closing.wait(10)
+            log.info("Running task %s...", self._task.name)
+            await self._task_archive.run_task(self._task)
 
             # send event
-            self.comm.send_event(TaskFinishedEvent(name=self._task.name, id=self._task.id))
+            await self.comm.send_event(TaskFinishedEvent(name=self._task.name, id=self._task.id))
 
             # finish
-            log.info('Finished task %s.', self._task.name)
+            log.info("Finished task %s.", self._task.name)
             self._task = None
 
-    def get_fits_header_before(self, namespaces: Optional[List[str]] = None, **kwargs: Any) \
-            -> Dict[str, Tuple[Any, str]]:
+    async def get_fits_header_before(
+        self, namespaces: Optional[List[str]] = None, **kwargs: Any
+    ) -> Dict[str, Tuple[Any, str]]:
         """Returns FITS header for the current status of this module.
 
         Args:
@@ -179,11 +156,11 @@ class Mastermind(Module, IAutonomous, IFitsHeaderBefore):
         # inside an observation?
         if self._task is not None:
             hdr = self._task.get_fits_headers()
-            hdr['TASK'] = self._task.name, 'Name of task'
-            hdr['REQNUM'] = str(self._task.id), 'Unique ID of task'
+            hdr["TASK"] = self._task.name, "Name of task"
+            hdr["REQNUM"] = str(self._task.id), "Unique ID of task"
             return hdr
         else:
             return {}
 
 
-__all__ = ['Mastermind']
+__all__ = ["Mastermind"]
