@@ -10,9 +10,10 @@ log = logging.getLogger(__name__)
 
 class StandAlone(Module):
     """Example module that only logs the given message forever in the given interval."""
-    __module__ = 'pyobs.modules.test'
 
-    def __init__(self, message: str = 'Hello world', interval: int = 10, **kwargs: Any):
+    __module__ = "pyobs.modules.test"
+
+    def __init__(self, message: str = "Hello world", interval: int = 10, **kwargs: Any):
         """Creates a new StandAlone object.
 
         Args:
@@ -39,4 +40,4 @@ class StandAlone(Module):
             await asyncio.sleep(self._interval)
 
 
-__all__ = ['StandAlone']
+__all__ = ["StandAlone"]
