@@ -7,10 +7,12 @@ and helper methods for creating other Objects.
 
 from __future__ import annotations
 
+import asyncio
 import copy
 import datetime
-import threading
-from typing import Union, Callable, TypeVar, Optional, Type, List, Tuple, Dict, Any, overload, TYPE_CHECKING
+import inspect
+from collections import Coroutine
+from typing import Union, Callable, TypeVar, Optional, Type, List, Tuple, Dict, Any, overload, TYPE_CHECKING, Awaitable
 import logging
 import pytz
 from astroplan import Observer
@@ -18,6 +20,8 @@ from astropy.coordinates import EarthLocation
 
 from pyobs.comm import Comm
 from pyobs.comm.dummy import DummyComm
+from pyobs.utils.parallel import event_wait
+
 if TYPE_CHECKING:
     from pyobs.vfs import VirtualFileSystem
 
@@ -25,28 +29,37 @@ log = logging.getLogger(__name__)
 
 
 """Class of an Object."""
-ObjectClass = TypeVar('ObjectClass')
-ProxyType = TypeVar('ProxyType')
+ObjectClass = TypeVar("ObjectClass")
+ProxyType = TypeVar("ProxyType")
 
 
 @overload
-def get_object(config_or_object: Union[Dict[str, Any], Any], object_class: Type[ObjectClass], **kwargs: Any) \
-        -> ObjectClass: ...
+def get_object(
+    config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+    object_class: Type[ObjectClass],
+    **kwargs: Any,
+) -> ObjectClass:
+    ...
 
 
 @overload
-def get_object(config_or_object: Union[Dict[str, Any], Any], object_class: None, **kwargs: Any) -> Any: ...
+def get_object(
+    config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any], object_class: None, **kwargs: Any
+) -> Any:
+    ...
 
 
-def get_object(config_or_object: Union[Dict[str, Any], Any], object_class: Optional[Type[ObjectClass]] = None,
-               **kwargs: Any) -> Union[ObjectClass, Any]:
+def get_object(
+    config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+    object_class: Optional[Type[ObjectClass]] = None,
+    **kwargs: Any,
+) -> Union[ObjectClass, Any]:
     """Creates object from config or returns object directly, both optionally after check of type.
 
     Args:
         config_or_object: A configuration dict or an object itself to create/check. If a dict with a class key
             is given, a new object is created.
         object_class: Class to check object against.
-        allow_none: if True, a None value does not trigger an exception
 
     Returns:
         (New) object (created from config) that optionally passed class check.
@@ -56,7 +69,7 @@ def get_object(config_or_object: Union[Dict[str, Any], Any], object_class: Optio
     """
 
     if config_or_object is None:
-        raise TypeError('No config or object given.')
+        raise TypeError("No config or object given.")
 
     elif isinstance(config_or_object, dict):
         # copy kwargs to config_or_object, so that we don't have any duplicates
@@ -66,27 +79,35 @@ def get_object(config_or_object: Union[Dict[str, Any], Any], object_class: Optio
         # a dict is given, so create object
         obj = create_object(config_or_object)
 
+    elif inspect.isclass(config_or_object):
+        # config_or_object is a type, so create it using its constructor
+        obj = config_or_object(**kwargs)
+
     else:
         # just use given object
         obj = config_or_object
 
     # do we need a type check and does the given object pass?
     if object_class is not None and not isinstance(obj, object_class):
-        raise TypeError('Provided object is not of requested type %s.' % object_class.__name__)
+        raise TypeError("Provided object is not of requested type %s." % object_class.__name__)
     return obj
 
 
 @overload
-def get_safe_object(config_or_object: Union[ObjectClass, Dict[str, Any]], object_class: Type[ObjectClass],
-                    **kwargs: Any) -> Optional[ObjectClass]: ...
+def get_safe_object(
+    config_or_object: Union[ObjectClass, Dict[str, Any]], object_class: Type[ObjectClass], **kwargs: Any
+) -> Optional[ObjectClass]:
+    ...
 
 
 @overload
-def get_safe_object(config_or_object: Union[ObjectClass, Any], object_class: None, **kwargs: Any) -> Optional[Any]: ...
+def get_safe_object(config_or_object: Union[ObjectClass, Any], object_class: None, **kwargs: Any) -> Optional[Any]:
+    ...
 
 
-def get_safe_object(config_or_object: Union[Dict[str, Any], Any], object_class: Optional[Type[ObjectClass]] = None,
-                    **kwargs: Any) -> Optional[Union[ObjectClass, Any]]:
+def get_safe_object(
+    config_or_object: Union[Dict[str, Any], Any], object_class: Optional[Type[ObjectClass]] = None, **kwargs: Any
+) -> Optional[Union[ObjectClass, Any]]:
     """Calls get_object in a safe way and returns None, if an exceptions thrown."""
     try:
         return get_object(config_or_object, object_class, **kwargs)
@@ -95,7 +116,7 @@ def get_safe_object(config_or_object: Union[Dict[str, Any], Any], object_class:
 
 
 def get_class_from_string(class_name: str) -> Type[Any]:
-    parts = class_name.split('.')
+    parts = class_name.split(".")
     module_name = ".".join(parts[:-1])
     cls: Type[Any] = __import__(module_name)
     for comp in parts[1:]:
@@ -105,14 +126,14 @@ def get_class_from_string(class_name: str) -> Type[Any]:
 
 def create_object(config: Dict[str, Any], *args: Any, **kwargs: Any) -> Any:
     # get class name
-    class_name = config['class']
+    class_name = config["class"]
 
     # create class
     klass = get_class_from_string(class_name)
 
     # remove class from kwargs
     cfg = copy.copy(config)
-    del cfg['class']
+    del cfg["class"]
 
     # create object
     return klass(*args, **cfg, **kwargs)
@@ -121,10 +142,15 @@ def create_object(config: Dict[str, Any], *args: Any, **kwargs: Any) -> Any:
 class Object:
     """Base class for all objects in *pyobs*."""
 
-    def __init__(self, vfs: Optional[Union['VirtualFileSystem', Dict[str, Any]]] = None,
-                 comm: Optional[Union[Comm, Dict[str, Any]]] = None, timezone: Union[str, datetime.tzinfo] = 'utc',
-                 location: Optional[Union[str, Dict[str, Any], EarthLocation]] = None,
-                 observer: Optional[Observer] = None, **kwargs: Any):
+    def __init__(
+        self,
+        vfs: Optional[Union["VirtualFileSystem", Dict[str, Any]]] = None,
+        comm: Optional[Union[Comm, Dict[str, Any]]] = None,
+        timezone: Union[str, datetime.tzinfo] = "utc",
+        location: Optional[Union[str, Dict[str, Any], EarthLocation]] = None,
+        observer: Optional[Observer] = None,
+        **kwargs: Any,
+    ):
         """
         .. note::
 
@@ -150,12 +176,6 @@ class Object:
         """
         from pyobs.vfs import VirtualFileSystem
 
-        # an event that will be fired when closing the module
-        self.closing = threading.Event()
-
-        # closing event
-        self.closing = threading.Event()
-
         # child objects
         self._child_objects: List[Any] = []
 
@@ -171,7 +191,7 @@ class Object:
         elif isinstance(timezone, str):
             self.timezone = pytz.timezone(timezone)
         else:
-            raise ValueError('Unknown format for timezone.')
+            raise ValueError("Unknown format for timezone.")
 
         # location
         if location is None:
@@ -181,16 +201,21 @@ class Object:
         elif isinstance(location, str):
             self.location = EarthLocation.of_site(location)
         elif isinstance(location, dict):
-            self.location = EarthLocation.from_geodetic(location['longitude'], location['latitude'],
-                                                        location['elevation'])
+            self.location = EarthLocation.from_geodetic(
+                location["longitude"], location["latitude"], location["elevation"]
+            )
         else:
-            raise ValueError('Unknown format for location.')
+            raise ValueError("Unknown format for location.")
 
         # create observer
         self.observer = observer
         if self.observer is None and self.location is not None and self.timezone is not None:
-            log.info('Setting location to longitude=%s, latitude=%s, and elevation=%s.',
-                     self.location.lon, self.location.lat, self.location.height)
+            log.info(
+                "Setting location to longitude=%s, latitude=%s, and elevation=%s.",
+                self.location.lon,
+                self.location.lat,
+                self.location.height,
+            )
             self.observer = Observer(location=self.location, timezone=timezone)
 
         # comm object
@@ -200,20 +225,22 @@ class Object:
         elif isinstance(comm, Comm):
             self.comm = comm
         elif isinstance(comm, dict):
-            log.info('Creating comm object...')
+            log.info("Creating comm object...")
             self.comm = get_object(comm, Comm)
         else:
-            raise ValueError('Invalid Comm object')
+            raise ValueError("Invalid Comm object")
 
         # opened?
         self._opened = False
 
-        # thread function(s)
-        self._threads: Dict[threading.Thread, Tuple[Callable[[], None], bool]] = {}
-        self._watchdog = threading.Thread(target=self._watchdog_func, name='watchdog')
+        # background tasks
+        self._background_tasks: Dict[
+            Callable[..., Coroutine[Any, Any, None]], Tuple[Optional[asyncio.Task[bool]], bool]
+        ] = {}
+        self._watchdog_task: Optional[asyncio.Task[None]] = None
 
-    def add_thread_func(self, func: Callable[[], None], restart: bool = True) -> threading.Thread:
-        """Add a new function that should be run in a thread.
+    def add_background_task(self, func: Callable[..., Coroutine[Any, Any, None]], restart: bool = True) -> None:
+        """Add a new function that should be run in the background.
 
         MUST be called in constructor of derived class or at least before calling open() on the object.
 
@@ -223,26 +250,25 @@ class Object:
         """
 
         # create thread
-        t = threading.Thread(target=Object._thread_func, name=func.__name__, args=(func,))
+        self._background_tasks[func] = (None, restart)
 
-        # add it
-        self._threads[t] = (func, restart)
-        return t
-
-    def open(self) -> None:
+    async def open(self) -> None:
         """Open module."""
 
-        # start threads and watchdog
-        for thread, (target, _) in self._threads.items():
-            log.info('Starting thread for %s...', target.__name__)
-            thread.start()
-        if len(self._threads) > 0 and self._watchdog:
-            self._watchdog.start()
+        # start background tasks
+        for func, (task, restart) in self._background_tasks.items():
+            log.info("Starting background task for %s...", func.__name__)
+            self._background_tasks[func] = (asyncio.create_task(self._background_func(func)), restart)
+        if len(self._background_tasks) > 0:
+            self._watchdog_task = asyncio.create_task(self._watchdog())
 
         # open child objects
         for obj in self._child_objects:
-            if hasattr(obj, 'open'):
-                obj.open()
+            if hasattr(obj, "open"):
+                if asyncio.iscoroutinefunction(obj.open):
+                    await obj.open()
+                else:
+                    obj.open()
 
         # success
         self._opened = True
@@ -252,85 +278,99 @@ class Object:
         """Whether object has been opened."""
         return self._opened
 
-    def close(self) -> None:
+    async def close(self) -> None:
         """Close module."""
 
-        # request closing of object (used for long-running methods)
-        self.closing.set()
-
         # close child objects
         for obj in self._child_objects:
-            if hasattr(obj, 'close'):
-                obj.close()
+            if hasattr(obj, "close"):
+                await obj.close()
 
         # join watchdog and then all threads
-        if self._watchdog and self._watchdog.is_alive():
-            self._watchdog.join()
-        for t in self._threads.keys():
-            if t.is_alive():
-                t.join()
+        if self._watchdog_task and not self._watchdog_task.done():
+            self._watchdog_task.cancel()
+        for func, (task, restart) in self._background_tasks.items():
+            if task and not task.done():
+                task.cancel()
 
     @staticmethod
-    def _thread_func(target: Callable[[], None]) -> None:
+    async def _background_func(target: Callable[..., Coroutine[Any, Any, None]]) -> None:
         """Run given function.
 
         Args:
             target: Function to run.
         """
         try:
-            target()
+            await target()
+
+        except asyncio.CancelledError:
+            # task was canceled
+            return
+
         except:
-            log.exception('Exception in thread method %s.' % target.__name__)
+            log.exception("Exception in thread method %s." % target.__name__)
 
     def quit(self) -> None:
         """Can be overloaded to quit program."""
-        ...
+        pass
 
-    def _watchdog_func(self) -> None:
+    async def _watchdog(self) -> None:
         """Watchdog thread that tries to restart threads if they quit."""
 
-        while not self.closing.is_set():
-            # get dead threads that need to be restarted
+        while True:
+            # get dead taks that need to be restarted
             dead = {}
-            for thread, (target, restart) in self._threads.items():
-                if not thread.is_alive():
-                    dead[thread] = (target, restart)
+            for func, (task, restart) in self._background_tasks.items():
+                if task.done():
+                    dead[func] = restart
 
-            # restart dead threads or quit
-            for thread, (target, restart) in dead.items():
+            # restart dead tasks or quit
+            for func, restart in dead.items():
                 if restart:
-                    log.error('Thread for %s has died, restarting...', target.__name__)
-                    del self._threads[thread]
-                    thread = self.add_thread_func(target, restart)
-                    thread.start()
+                    log.error("Background task for %s has died, restarting...", func.__name__)
+                    del self._background_tasks[func]
+                    self._background_tasks[func] = (asyncio.create_task(self._background_func(func)), restart)
                 else:
-                    log.error('Thread for %s has died, quitting...', target.__name__)
+                    log.error("Background task for %s has died, quitting...", func.__name__)
                     self.quit()
                     return
 
             # sleep a little
-            self.closing.wait(1)
-
-    def check_running(self) -> bool:
-        """Check, whether an object should be closing. Can be polled by long-running methods.
-
-        Raises:
-            InterruptedError: Raised when object should be closing.
-        """
-        if self.closing.is_set():
-            raise InterruptedError
-        return True
+            await asyncio.sleep(1)
 
     @overload
-    def get_object(self, config_or_object: Union[Dict[str, Any], Any], object_class: Type[ObjectClass],
-                   copy_comm: bool = True, **kwargs: Any) -> ObjectClass: ...
+    def get_object(
+        self,
+        config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+        object_class: Type[ObjectClass],
+        copy_comm: bool = True,
+        **kwargs: Any,
+    ) -> ObjectClass:
+        ...
 
     @overload
-    def get_object(self, config_or_object: Union[Dict[str, Any], Any], object_class: None, copy_comm: bool = True,
-                   **kwargs: Any) -> Any: ...
+    def get_object(
+        self, config_or_object: Type[ObjectClass], object_class: None = None, copy_comm: bool = True, **kwargs: Any
+    ) -> ObjectClass:
+        ...
 
-    def get_object(self, config_or_object: Union[Dict[str, Any], Any], object_class: Optional[Type[ObjectClass]] = None,
-                   copy_comm: bool = True, **kwargs: Any) -> Union[ObjectClass, Any]:
+    @overload
+    def get_object(
+        self,
+        config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+        object_class: None,
+        copy_comm: bool = True,
+        **kwargs: Any,
+    ) -> Any:
+        ...
+
+    def get_object(
+        self,
+        config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+        object_class: Optional[Type[ObjectClass]] = None,
+        copy_comm: bool = True,
+        **kwargs: Any,
+    ) -> Union[ObjectClass, Any]:
         """Creates object from config or returns object directly, both optionally after check of type.
 
         Args:
@@ -348,46 +388,82 @@ class Object:
 
         # set parameters
         params = copy.copy(kwargs)
-        params.update({
-            'timezone': self.timezone,
-            'location': self.location,
-            'vfs': self.vfs
-        })
+        params.update(
+            {"timezone": self.timezone, "location": self.location, "vfs": self.vfs, "observer": self.observer}
+        )
         if copy_comm:
-            params['comm'] = self.comm
+            params["comm"] = self.comm
 
         # get it
         return get_object(config_or_object, object_class, **params)
 
     @overload
-    def get_safe_object(self, config_or_object: Union[ObjectClass, Dict[str, Any]], object_class: Type[ObjectClass],
-                        copy_comm: bool = True, **kwargs: Any) -> Optional[ObjectClass]: ...
+    def get_safe_object(
+        self,
+        config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+        object_class: Type[ObjectClass],
+        copy_comm: bool = True,
+        **kwargs: Any,
+    ) -> Optional[ObjectClass]:
+        ...
 
     @overload
-    def get_safe_object(self, config_or_object: Union[ObjectClass, Any], object_class: None,
-                        copy_comm: bool = True, **kwargs: Any) -> Optional[Any]: ...
+    def get_safe_object(
+        self,
+        config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+        object_class: None,
+        copy_comm: bool = True,
+        **kwargs: Any,
+    ) -> Optional[Any]:
+        ...
 
-    def get_safe_object(self, config_or_object: Union[Dict[str, Any], Any],
-                        object_class: Optional[Type[ObjectClass]] = None, copy_comm: bool = True,
-                        **kwargs: Any) -> Optional[Union[ObjectClass, Any]]:
+    def get_safe_object(
+        self,
+        config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+        object_class: Optional[Type[ObjectClass]] = None,
+        copy_comm: bool = True,
+        **kwargs: Any,
+    ) -> Optional[Union[ObjectClass, Any]]:
         """Calls get_object in a safe way and returns None, if an exceptions thrown."""
         try:
             return self.get_object(config_or_object, object_class=object_class, copy_comm=copy_comm, **kwargs)
         except Exception:
-            log.exception('test')
+            log.exception("test")
             return None
 
     @overload
-    def add_child_object(self, config_or_object: Union[Dict[str, Any], Any], object_class: Type[ObjectClass],
-                         copy_comm: bool = True, **kwargs: Any) -> ObjectClass: ...
+    def add_child_object(
+        self,
+        config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+        object_class: Type[ObjectClass],
+        copy_comm: bool = True,
+        **kwargs: Any,
+    ) -> ObjectClass:
+        ...
 
     @overload
-    def add_child_object(self, config_or_object: Union[Dict[str, Any], Any], object_class: None, copy_comm: bool = True,
-                         **kwargs: Any) -> Any: ...
+    def add_child_object(
+        self, config_or_object: Type[ObjectClass], object_class: None = None, copy_comm: bool = True, **kwargs: Any
+    ) -> ObjectClass:
+        ...
 
-    def add_child_object(self, config_or_object: Union[Dict[str, Any], Any],
-                         object_class: Optional[Type[ObjectClass]] = None, copy_comm: bool = True,
-                         **kwargs: Any) -> Union[ObjectClass, Any]:
+    @overload
+    def add_child_object(
+        self,
+        config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+        object_class: None,
+        copy_comm: bool = True,
+        **kwargs: Any,
+    ) -> Any:
+        ...
+
+    def add_child_object(
+        self,
+        config_or_object: Union[Dict[str, Any], ObjectClass, Type[ObjectClass], Any],
+        object_class: Optional[Type[ObjectClass]] = None,
+        copy_comm: bool = True,
+        **kwargs: Any,
+    ) -> Union[ObjectClass, Any]:
         """Create a new sub-module, which will automatically be opened and closed.
 
         Args:
@@ -409,15 +485,16 @@ class Object:
         return obj
 
     @overload
-    def proxy(self, name_or_object: Union[str, object], obj_type: Type[ProxyType]) -> ProxyType:
+    async def proxy(self, name_or_object: Union[str, object], obj_type: Type[ProxyType]) -> ProxyType:
         ...
 
     @overload
-    def proxy(self, name_or_object: Union[str, object], obj_type: Optional[Type[ProxyType]] = None) -> Any:
+    async def proxy(self, name_or_object: Union[str, object], obj_type: Optional[Type[ProxyType]] = None) -> Any:
         ...
 
-    def proxy(self, name_or_object: Union[str, object], obj_type: Optional[Type[ProxyType]] = None) \
-            -> Union[Any, ProxyType]:
+    async def proxy(
+        self, name_or_object: Union[str, object], obj_type: Optional[Type[ProxyType]] = None
+    ) -> Union[Any, ProxyType]:
         """Returns object directly if it is of given type. Otherwise get proxy of client with given name and check type.
 
         If name_or_object is an object:
@@ -438,7 +515,7 @@ class Object:
         Raises:
             ValueError: If proxy does not exist or wrong type.
         """
-        return self.comm.proxy(name_or_object, obj_type)
+        return await self.comm.proxy(name_or_object, obj_type)
 
 
-__all__ = ['get_object', 'get_class_from_string', 'create_object', 'Object']
+__all__ = ["get_object", "get_class_from_string", "create_object", "Object"]
