@@ -53,14 +53,16 @@ Currently supported are these types of file access:
 The base class for all of these classes is :class:`~pyobs.vfs.VFSFile`.
 
 """
-__title__ = 'Virtual File System'
+__title__ = "Virtual File System"
 
-from .vfs import VirtualFileSystem, VFSFile
+from .vfs import VirtualFileSystem
+from .file import VFSFile
 from .localfile import LocalFile
 from .httpfile import HttpFile
 from .memfile import MemoryFile
 from .sshfile import SSHFile
-from .tarfile import TarFile
 from .tempfile import TempFile
-from .gzippipe import GzipReader, GzipWriter
 from .archivefile import ArchiveFile
+
+
+__all__ = ["VirtualFileSystem", "VFSFile", "LocalFile", "HttpFile", "MemoryFile", "SSHFile", "TempFile", "ArchiveFile"]
